@@ -10,13 +10,13 @@ use Moose::Role;
 # use Storable 3.15 qw(dclone);
 # use Try::Tiny;
 
-our $VERSION='1.00';
+our $VERSION='1.01';
 
 =head1 NAME
 
 Vote::Count::Score
 
-=head1 VERSION 1.00
+=head1 VERSION 1.01
 
 =cut
 
@@ -37,11 +37,11 @@ use Vote::Count::RankCount;
     );
   my $scored = $RangeElection->Score();
 
-=head1 Score
+=head1 Range Score Methods
 
 When Range (Cardinal) Ballots are used, it is simple and obvious to total the scores provided by the voters. This contrasts to the related Borda Method which assigns scores based on position on a Ranked Ballot.
 
-=head1 Method Score
+=head2 Score
 
 Returns a RankCount Object with the choices scored using the scores set by the voters, for Range Ballots.
 
@@ -62,6 +62,30 @@ sub Score ( $self, $active = undef ) {
   return Vote::Count::RankCount->Rank( \%scores );
 }
 
+=head2 RangeBallotPair
+
+Used for pairings against Range Ballots. Used by Condorcet and STAR.
+
+  where $I is a Vote::Count object created with a Range Ballot Set.
+
+  my ( $countA, $countB ) = $I->RangeBallotPair( $A, $B) ;
+
+=cut
+
+sub RangeBallotPair ( $self, $A, $B ) {
+  my $countA   = 0;
+  my $countB   = 0;
+  my $approval = $self->Approval();
+  for my $ballot ( $self->BallotSet()->{'ballots'}->@* ) {
+    my $prefA = $ballot->{'votes'}{$A} || 0;
+    my $prefB = $ballot->{'votes'}{$B} || 0;
+    if    ( $prefA > $prefB ) { $countA += $ballot->{'count'} }
+    elsif ( $prefA < $prefB ) { $countB += $ballot->{'count'} }
+    else                      { }
+  }
+  return ( $countA, $countB );
+}
+
 1;
 
 #FOOTER
